@@ -1,5 +1,3 @@
-from .auth.add import add_auth
-from .auth.sugar import optional_user, public_router, require_roles, require_user
 from .cache.add import setup_caching
 from .deps import Require
 from .dual_router import DualAPIRouter, dualize_router
@@ -18,10 +16,4 @@ __all__ = [
     "easy_service_api",
     "easy_service_app",
     "setup_caching",
-    # Auth
-    "add_auth",
-    "public_router",
-    "optional_user",
-    "require_user",
-    "require_roles",
 ]
