@@ -1,9 +1,8 @@
 from typing import Annotated, Any, Optional, Sequence, Type, TypeVar, cast
 
-from fastapi import Body, Depends, HTTPException
+from fastapi import APIRouter, Body, Depends, HTTPException
 from pydantic import BaseModel
 
-from svc_infra.api.fastapi.auth.sugar import public_router
 from svc_infra.api.fastapi.db.http import (
     LimitOffsetParams,
     OrderParams,
@@ -14,7 +13,6 @@ from svc_infra.api.fastapi.db.http import (
     dep_order,
     dep_search,
 )
-from svc_infra.api.fastapi.dual_router import DualAPIRouter
 from svc_infra.db.sql.service import SqlService
 
 from .session import SqlSessionDep
@@ -37,7 +35,9 @@ def make_crud_router_plus_sql(
     default_ordering: Optional[str] = None,
     allowed_order_fields: Optional[list[str]] = None,
     mount_under_db_prefix: bool = True,
-) -> DualAPIRouter:
+) -> APIRouter:
+    from svc_infra.api.fastapi.auth import public_router
+
     router_prefix = ("/_sql" + prefix) if mount_under_db_prefix else prefix
     router = public_router(
         prefix=router_prefix,
